@@ -1,6 +1,5 @@
 "plotTrainTest" <-
-function(x=Golub.BM, nfeatures=c(11,11), cl=cancer.BM,
-           traintest=divideUp(cancer.BM),
+function(x, nfeatures, cl, traintest,
            titles=c("A: I/II (train with I, scores are for II)",
              "B: II/I (train with II, scores are for I)")){
     oldpar <- par(mfrow=c(1,2), pty="s")
@@ -15,7 +14,7 @@ function(x=Golub.BM, nfeatures=c(11,11), cl=cancer.BM,
     ord1 <- orderFeatures(x, cl, subset=train)
     df1 <- data.frame(t(x[ord1[1:nf1], train]))
     df2 <- data.frame(t(x[ord1[1:nf1], testset]))
-    df1.lda <- lda(df1, cl1)    
+    df1.lda <- lda(df1, cl1)
     scores <- predict(df1.lda, newdata=df2)$x
     scoreplot(scorelist=list(scores=scores, cl=cl2,
              nfeatures=nfeatures[1], other=NULL, cl.other=NULL),
@@ -25,11 +24,11 @@ function(x=Golub.BM, nfeatures=c(11,11), cl=cancer.BM,
     ord2 <- orderFeatures(x, cl, subset=testset)
     df2 <- data.frame(t(x[ord2[1:nf2], testset]))
     df1 <- data.frame(t(x[ord2[1:nf2], train]))
-    df2.lda <- lda(df2, cl2)    
+    df2.lda <- lda(df2, cl2)
     scores <- predict(df2.lda, newdata=df1)$x
     scoreplot(scorelist=list(scores=scores, cl=cl1,
              nfeatures=nfeatures[2], other=NULL, cl.other=NULL),
            prefix.title="")
-    mtext(side=3, line=2, titles[2], adj=0)    
+    mtext(side=3, line=2, titles[2], adj=0)
   }
 
